==> flink-1.20.3-src.tgz: flink-1.20.3/flink-runtime/src/main/java/org/apache/flink/runtime/jobmaster/slotpool/BlocklistDeclarativeSlotPoolFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.jobmaster.slotpool;

import org.apache.flink.api.common.JobID;
import org.apache.flink.api.common.time.Time;
import org.apache.flink.runtime.blocklist.BlockedTaskManagerChecker;
import org.apache.flink.runtime.slots.ResourceRequirement;

import java.util.Collection;
import java.util.function.Consumer;

import static org.apache.flink.util.Preconditions.checkNotNull;

/** Factory for {@link BlocklistDeclarativeSlotPool}. */
public class BlocklistDeclarativeSlotPoolFactory implements DeclarativeSlotPoolFactory {

    private final BlockedTaskManagerChecker blockedTaskManagerChecker;

    public BlocklistDeclarativeSlotPoolFactory(
            BlockedTaskManagerChecker blockedTaskManagerChecker) {
        this.blockedTaskManagerChecker = checkNotNull(blockedTaskManagerChecker);
    }

    @Override
    public DeclarativeSlotPool create(
            JobID jobId,
            Consumer<? super Collection<ResourceRequirement>> notifyNewResourceRequirements,
            Time idleSlotTimeout,
            Time rpcTimeout) {
        return new BlocklistDeclarativeSlotPool(
                jobId,
                new DefaultAllocatedSlotPool(),
                notifyNewResourceRequirements,
                blockedTaskManagerChecker,
                idleSlotTimeout,
                rpcTimeout);
    }
}

==> flink-2.1.0-src.tgz: flink-2.1.0/flink-runtime/src/main/java/org/apache/flink/runtime/jobmaster/slotpool/BlocklistDeclarativeSlotPoolFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.jobmaster.slotpool;

import org.apache.flink.api.common.JobID;
import org.apache.flink.runtime.blocklist.BlockedTaskManagerChecker;
import org.apache.flink.runtime.concurrent.ComponentMainThreadExecutor;
import org.apache.flink.runtime.slots.ResourceRequirement;

import java.time.Duration;
import java.util.Collection;
import java.util.function.Consumer;

import static org.apache.flink.util.Preconditions.checkNotNull;

/** Factory for {@link BlocklistDeclarativeSlotPool}. */
public class BlocklistDeclarativeSlotPoolFactory implements DeclarativeSlotPoolFactory {

    private final BlockedTaskManagerChecker blockedTaskManagerChecker;

    public BlocklistDeclarativeSlotPoolFactory(
            BlockedTaskManagerChecker blockedTaskManagerChecker) {
        this.blockedTaskManagerChecker = checkNotNull(blockedTaskManagerChecker);
    }

    @Override
    public DeclarativeSlotPool create(
            JobID jobId,
            Consumer<? super Collection<ResourceRequirement>> notifyNewResourceRequirements,
            Duration idleSlotTimeout,
            Duration rpcTimeout,
            Duration slotRequestMaxInterval,
            ComponentMainThreadExecutor componentMainThreadExecutor) {
        return new BlocklistDeclarativeSlotPool(
                jobId,
                new DefaultAllocatedSlotPool(),
                notifyNewResourceRequirements,
                blockedTaskManagerChecker,
                idleSlotTimeout,
                rpcTimeout,
                slotRequestMaxInterval,
                componentMainThreadExecutor);
    }
}
